@@ -1,5 +1,5 @@
 #[cfg(feature = "cors-middleware")]
-pub use cors::{MiddlewareLayer as CorsLayer, Middleware as CorsMiddleware};
+pub use cors::{Middleware as CorsMiddleware, MiddlewareLayer as CorsLayer};
 
 #[cfg(feature = "cors-middleware")]
 mod cors;
